@@ -41,6 +41,7 @@ API_PATH = {
     'activity': 'api/activities/{activity_id}.json',
     'activity_export': 'api/activities/{activity_id}/export',
     'activity_move': 'api/activities/{activity_id}/move_activity',
+    'activities_bulk_update': 'api/activities/bulk_update',
     'parts': 'api/parts.json',
     'part': 'api/parts/{part_id}.json',
     'properties': 'api/properties.json',
@@ -60,6 +61,7 @@ API_PATH = {
     'service_execution_notebook_url': 'api/service_executions/{service_execution_id}/notebook_url',
     'service_execution_log': 'api/service_executions/{service_execution_id}/log',
     'users': 'api/users.json',
+    'user_current': 'api/users/get_current_user',
     'teams': 'api/teams.json',
     'team': 'api/teams/{team_id}.json',
     'team_add_members': 'api/teams/{team_id}/add_members',
@@ -103,15 +105,28 @@ API_PATH = {
     'widgets_bulk_delete': 'api/widgets/bulk_delete',
     'widgets_bulk_update': 'api/widgets/bulk_update',
     'widgets_schemas': 'api/widgets/schemas',
+    'notifications': 'api/v3/notifications.json',
+    'notification': 'api/v3/notifications/{notification_id}.json',
+    'notification_share_activity_link': 'api/v3/notifications/share_activity_link',
+    'notification_share_activity_pdf': 'api/v3/notifications/share_activity_pdf',
+    'banners': 'api/v3/banners.json',
+    'banner': 'api/v3/banners/{banner_id}.json',
+    'banner_active': 'api/v3/banners/active.json',
 }
 API_QUERY_PARAM_ALL_FIELDS = {'fields': '__all__'}
 API_EXTRA_PARAMS = {
     'activity': {'fields': ",".join(
         ['id', 'name', 'ref', 'description', 'created_at', 'updated_at', 'activity_type', 'classification', 'tags',
-         'progress', 'assignees_ids', 'start_date', 'due_date', 'status', 'parent_id', 'scope_id', 'customization'])},
+         'progress', 'assignees_ids', 'start_date', 'due_date', 'status', 'parent_id', 'scope_id', 'customization',
+         'activity_options'])},
     'activities': {'fields': ",".join(
         ['id', 'name', 'ref', 'description', 'created_at', 'updated_at', 'activity_type', 'classification', 'tags',
-         'progress', 'assignees_ids', 'start_date', 'due_date', 'status', 'parent_id', 'scope_id', 'customization'])},
+         'progress', 'assignees_ids', 'start_date', 'due_date', 'status', 'parent_id', 'scope_id', 'customization',
+         'activity_options'])},
+    'banner': {'fields': ",".join(
+        ['id', 'text', 'icon', 'is_active', 'active_from', 'active_until', 'url', 'created_at', 'updated_at'])},
+    'banners': {'fields': ",".join(
+        ['id', 'text', 'icon', 'is_active', 'active_from', 'active_until', 'url', 'created_at', 'updated_at'])},
     'scope2': {'fields': ",".join(
         ['id', 'name', 'ref', 'text', 'created_at', 'updated_at', 'start_date', 'due_date', 'status', 'category',
          'progress', 'members', 'team', 'tags', 'scope_options', 'team_id_name', 'workflow_root_id'])},
@@ -144,4 +159,8 @@ API_EXTRA_PARAMS = {
     'widget': {'fields': ",".join(
         ['id', 'name', 'ref', 'created_at', 'updated_at', 'title', 'widget_type', 'meta', 'order', 'activity_id',
          'parent_id', 'progress', 'has_subwidgets', 'scope_id'])},
+    'notifications': {'fields': ",".join(
+        ['id', 'subject', 'status', 'message', 'team', 'created_at', 'options', 'updated_at'])},
+    'notification': {'fields': ",".join(
+        ['id', 'subject', 'status', 'message', 'team', 'created_at', 'options', 'updated_at'])},
 }
